# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class MigrationStatusReplyObj(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'duration_time': 'str',
        'last_status_message': 'str',
        'max_name_length': 'int',
        'max_value_length': 'int',
        'migration_id': 'str',
        'migration_items': 'MigrationItems',
        'migration_name': 'str',
        'migration_state': 'str',
        'migration_type': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'duration_time': 'duration_time',
        'last_status_message': 'last_status_message',
        'max_name_length': 'max_name_length',
        'max_value_length': 'max_value_length',
        'migration_id': 'migration_id',
        'migration_items': 'migration_items',
        'migration_name': 'migration_name',
        'migration_state': 'migration_state',
        'migration_type': 'migration_type',
        'start_time': 'start_time'
    }

    def __init__(self, duration_time=None, last_status_message=None, max_name_length=None, max_value_length=None, migration_id=None, migration_items=None, migration_name=None, migration_state=None, migration_type=None, start_time=None, local_vars_configuration=None):  # noqa: E501
        """MigrationStatusReplyObj - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._duration_time = None
        self._last_status_message = None
        self._max_name_length = None
        self._max_value_length = None
        self._migration_id = None
        self._migration_items = None
        self._migration_name = None
        self._migration_state = None
        self._migration_type = None
        self._start_time = None
        self.discriminator = None

        if duration_time is not None:
            self.duration_time = duration_time
        if last_status_message is not None:
            self.last_status_message = last_status_message
        if max_name_length is not None:
            self.max_name_length = max_name_length
        if max_value_length is not None:
            self.max_value_length = max_value_length
        if migration_id is not None:
            self.migration_id = migration_id
        if migration_items is not None:
            self.migration_items = migration_items
        if migration_name is not None:
            self.migration_name = migration_name
        if migration_state is not None:
            self.migration_state = migration_state
        if migration_type is not None:
            self.migration_type = migration_type
        if start_time is not None:
            self.start_time = start_time

    @property
    def duration_time(self):
        """Gets the duration_time of this MigrationStatusReplyObj.  # noqa: E501


        :return: The duration_time of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._duration_time

    @duration_time.setter
    def duration_time(self, duration_time):
        """Sets the duration_time of this MigrationStatusReplyObj.


        :param duration_time: The duration_time of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._duration_time = duration_time

    @property
    def last_status_message(self):
        """Gets the last_status_message of this MigrationStatusReplyObj.  # noqa: E501


        :return: The last_status_message of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._last_status_message

    @last_status_message.setter
    def last_status_message(self, last_status_message):
        """Sets the last_status_message of this MigrationStatusReplyObj.


        :param last_status_message: The last_status_message of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._last_status_message = last_status_message

    @property
    def max_name_length(self):
        """Gets the max_name_length of this MigrationStatusReplyObj.  # noqa: E501


        :return: The max_name_length of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._max_name_length

    @max_name_length.setter
    def max_name_length(self, max_name_length):
        """Sets the max_name_length of this MigrationStatusReplyObj.


        :param max_name_length: The max_name_length of this MigrationStatusReplyObj.  # noqa: E501
        :type: int
        """

        self._max_name_length = max_name_length

    @property
    def max_value_length(self):
        """Gets the max_value_length of this MigrationStatusReplyObj.  # noqa: E501


        :return: The max_value_length of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: int
        """
        return self._max_value_length

    @max_value_length.setter
    def max_value_length(self, max_value_length):
        """Sets the max_value_length of this MigrationStatusReplyObj.


        :param max_value_length: The max_value_length of this MigrationStatusReplyObj.  # noqa: E501
        :type: int
        """

        self._max_value_length = max_value_length

    @property
    def migration_id(self):
        """Gets the migration_id of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_id of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_id

    @migration_id.setter
    def migration_id(self, migration_id):
        """Sets the migration_id of this MigrationStatusReplyObj.


        :param migration_id: The migration_id of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_id = migration_id

    @property
    def migration_items(self):
        """Gets the migration_items of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_items of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: MigrationItems
        """
        return self._migration_items

    @migration_items.setter
    def migration_items(self, migration_items):
        """Sets the migration_items of this MigrationStatusReplyObj.


        :param migration_items: The migration_items of this MigrationStatusReplyObj.  # noqa: E501
        :type: MigrationItems
        """

        self._migration_items = migration_items

    @property
    def migration_name(self):
        """Gets the migration_name of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_name of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_name

    @migration_name.setter
    def migration_name(self, migration_name):
        """Sets the migration_name of this MigrationStatusReplyObj.


        :param migration_name: The migration_name of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_name = migration_name

    @property
    def migration_state(self):
        """Gets the migration_state of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_state of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_state

    @migration_state.setter
    def migration_state(self, migration_state):
        """Sets the migration_state of this MigrationStatusReplyObj.


        :param migration_state: The migration_state of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_state = migration_state

    @property
    def migration_type(self):
        """Gets the migration_type of this MigrationStatusReplyObj.  # noqa: E501


        :return: The migration_type of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._migration_type

    @migration_type.setter
    def migration_type(self, migration_type):
        """Sets the migration_type of this MigrationStatusReplyObj.


        :param migration_type: The migration_type of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._migration_type = migration_type

    @property
    def start_time(self):
        """Gets the start_time of this MigrationStatusReplyObj.  # noqa: E501


        :return: The start_time of this MigrationStatusReplyObj.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this MigrationStatusReplyObj.


        :param start_time: The start_time of this MigrationStatusReplyObj.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MigrationStatusReplyObj):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MigrationStatusReplyObj):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateTokenizer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alphabet': 'str',
        'decoding_template': 'str',
        'delete_protection': 'str',
        'encoding_template': 'str',
        'encryption_key_name': 'str',
        'json': 'bool',
        'metadata': 'str',
        'name': 'str',
        'pattern': 'str',
        'tag': 'list[str]',
        'template_type': 'str',
        'token': 'str',
        'tokenizer_type': 'str',
        'tweak_type': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'alphabet': 'alphabet',
        'decoding_template': 'decoding-template',
        'delete_protection': 'delete_protection',
        'encoding_template': 'encoding-template',
        'encryption_key_name': 'encryption-key-name',
        'json': 'json',
        'metadata': 'metadata',
        'name': 'name',
        'pattern': 'pattern',
        'tag': 'tag',
        'template_type': 'template-type',
        'token': 'token',
        'tokenizer_type': 'tokenizer-type',
        'tweak_type': 'tweak-type',
        'uid_token': 'uid-token'
    }

    def __init__(self, alphabet=None, decoding_template=None, delete_protection=None, encoding_template=None, encryption_key_name=None, json=None, metadata=None, name=None, pattern=None, tag=None, template_type=None, token=None, tokenizer_type=None, tweak_type=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """CreateTokenizer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alphabet = None
        self._decoding_template = None
        self._delete_protection = None
        self._encoding_template = None
        self._encryption_key_name = None
        self._json = None
        self._metadata = None
        self._name = None
        self._pattern = None
        self._tag = None
        self._template_type = None
        self._token = None
        self._tokenizer_type = None
        self._tweak_type = None
        self._uid_token = None
        self.discriminator = None

        if alphabet is not None:
            self.alphabet = alphabet
        if decoding_template is not None:
            self.decoding_template = decoding_template
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if encoding_template is not None:
            self.encoding_template = encoding_template
        if encryption_key_name is not None:
            self.encryption_key_name = encryption_key_name
        if json is not None:
            self.json = json
        if metadata is not None:
            self.metadata = metadata
        self.name = name
        if pattern is not None:
            self.pattern = pattern
        if tag is not None:
            self.tag = tag
        self.template_type = template_type
        if token is not None:
            self.token = token
        self.tokenizer_type = tokenizer_type
        if tweak_type is not None:
            self.tweak_type = tweak_type
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def alphabet(self):
        """Gets the alphabet of this CreateTokenizer.  # noqa: E501

        Alphabet to use in regexp vaultless tokenization  # noqa: E501

        :return: The alphabet of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._alphabet

    @alphabet.setter
    def alphabet(self, alphabet):
        """Sets the alphabet of this CreateTokenizer.

        Alphabet to use in regexp vaultless tokenization  # noqa: E501

        :param alphabet: The alphabet of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._alphabet = alphabet

    @property
    def decoding_template(self):
        """Gets the decoding_template of this CreateTokenizer.  # noqa: E501

        The Decoding output template to use in regexp vaultless tokenization  # noqa: E501

        :return: The decoding_template of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._decoding_template

    @decoding_template.setter
    def decoding_template(self, decoding_template):
        """Sets the decoding_template of this CreateTokenizer.

        The Decoding output template to use in regexp vaultless tokenization  # noqa: E501

        :param decoding_template: The decoding_template of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._decoding_template = decoding_template

    @property
    def delete_protection(self):
        """Gets the delete_protection of this CreateTokenizer.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this CreateTokenizer.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def encoding_template(self):
        """Gets the encoding_template of this CreateTokenizer.  # noqa: E501

        The Encoding output template to use in regexp vaultless tokenization  # noqa: E501

        :return: The encoding_template of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._encoding_template

    @encoding_template.setter
    def encoding_template(self, encoding_template):
        """Sets the encoding_template of this CreateTokenizer.

        The Encoding output template to use in regexp vaultless tokenization  # noqa: E501

        :param encoding_template: The encoding_template of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._encoding_template = encoding_template

    @property
    def encryption_key_name(self):
        """Gets the encryption_key_name of this CreateTokenizer.  # noqa: E501

        AES key name to use in vaultless tokenization  # noqa: E501

        :return: The encryption_key_name of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._encryption_key_name

    @encryption_key_name.setter
    def encryption_key_name(self, encryption_key_name):
        """Sets the encryption_key_name of this CreateTokenizer.

        AES key name to use in vaultless tokenization  # noqa: E501

        :param encryption_key_name: The encryption_key_name of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._encryption_key_name = encryption_key_name

    @property
    def json(self):
        """Gets the json of this CreateTokenizer.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateTokenizer.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateTokenizer.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateTokenizer.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def metadata(self):
        """Gets the metadata of this CreateTokenizer.  # noqa: E501

        A metadata about the tokenizer  # noqa: E501

        :return: The metadata of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateTokenizer.

        A metadata about the tokenizer  # noqa: E501

        :param metadata: The metadata of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def name(self):
        """Gets the name of this CreateTokenizer.  # noqa: E501

        Tokenizer name  # noqa: E501

        :return: The name of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateTokenizer.

        Tokenizer name  # noqa: E501

        :param name: The name of this CreateTokenizer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def pattern(self):
        """Gets the pattern of this CreateTokenizer.  # noqa: E501

        Pattern to use in regexp vaultless tokenization  # noqa: E501

        :return: The pattern of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this CreateTokenizer.

        Pattern to use in regexp vaultless tokenization  # noqa: E501

        :param pattern: The pattern of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._pattern = pattern

    @property
    def tag(self):
        """Gets the tag of this CreateTokenizer.  # noqa: E501

        List of the tags attached to this key  # noqa: E501

        :return: The tag of this CreateTokenizer.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this CreateTokenizer.

        List of the tags attached to this key  # noqa: E501

        :param tag: The tag of this CreateTokenizer.  # noqa: E501
        :type: list[str]
        """

        self._tag = tag

    @property
    def template_type(self):
        """Gets the template_type of this CreateTokenizer.  # noqa: E501

        Which template type this tokenizer is used for [SSN,CreditCard,USPhoneNumber,Email,Regexp]  # noqa: E501

        :return: The template_type of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._template_type

    @template_type.setter
    def template_type(self, template_type):
        """Sets the template_type of this CreateTokenizer.

        Which template type this tokenizer is used for [SSN,CreditCard,USPhoneNumber,Email,Regexp]  # noqa: E501

        :param template_type: The template_type of this CreateTokenizer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and template_type is None:  # noqa: E501
            raise ValueError("Invalid value for `template_type`, must not be `None`")  # noqa: E501

        self._template_type = template_type

    @property
    def token(self):
        """Gets the token of this CreateTokenizer.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateTokenizer.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def tokenizer_type(self):
        """Gets the tokenizer_type of this CreateTokenizer.  # noqa: E501

        Tokenizer type  # noqa: E501

        :return: The tokenizer_type of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._tokenizer_type

    @tokenizer_type.setter
    def tokenizer_type(self, tokenizer_type):
        """Sets the tokenizer_type of this CreateTokenizer.

        Tokenizer type  # noqa: E501

        :param tokenizer_type: The tokenizer_type of this CreateTokenizer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tokenizer_type is None:  # noqa: E501
            raise ValueError("Invalid value for `tokenizer_type`, must not be `None`")  # noqa: E501

        self._tokenizer_type = tokenizer_type

    @property
    def tweak_type(self):
        """Gets the tweak_type of this CreateTokenizer.  # noqa: E501

        The tweak type to use in vaultless tokenization [Supplied, Generated, Internal, Masking]  # noqa: E501

        :return: The tweak_type of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._tweak_type

    @tweak_type.setter
    def tweak_type(self, tweak_type):
        """Sets the tweak_type of this CreateTokenizer.

        The tweak type to use in vaultless tokenization [Supplied, Generated, Internal, Masking]  # noqa: E501

        :param tweak_type: The tweak_type of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._tweak_type = tweak_type

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateTokenizer.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateTokenizer.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateTokenizer.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateTokenizer.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTokenizer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTokenizer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_create_producer_artifactory_output import GatewayCreateProducerArtifactoryOutput  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayCreateProducerArtifactoryOutput(unittest.TestCase):
    """GatewayCreateProducerArtifactoryOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayCreateProducerArtifactoryOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_create_producer_artifactory_output.GatewayCreateProducerArtifactoryOutput()  # noqa: E501
        if include_optional :
            return GatewayCreateProducerArtifactoryOutput(
                producer_details = akeyless.models.ds_producer_details.DSProducerDetails(
                    active = True, 
                    admin_name = '0', 
                    admin_pwd = '0', 
                    admin_rotation_interval_days = 56, 
                    allow_subdomains = True, 
                    allowed_domains = '0', 
                    artifactory_admin_apikey = '0', 
                    artifactory_admin_username = '0', 
                    artifactory_base_url = '0', 
                    artifactory_token_audience = '0', 
                    artifactory_token_scope = '0', 
                    auto_generated_folder = '0', 
                    aws_access_key_id = '0', 
                    aws_access_mode = '0', 
                    aws_region = '0', 
                    aws_role_arns = '0', 
                    aws_secret_access_key = '0', 
                    aws_session_token = '0', 
                    aws_user_console_access = True, 
                    aws_user_groups = '0', 
                    aws_user_policies = '0', 
                    aws_user_programmatic_access = True, 
                    azure_app_object_id = '0', 
                    azure_client_id = '0', 
                    azure_client_secret = '0', 
                    azure_tenant_id = '0', 
                    azure_user_groups_obj_id = '0', 
                    azure_user_portal_access = True, 
                    azure_user_programmatic_access = True, 
                    azure_user_roles_template_id = '0', 
                    chef_organizations = '0', 
                    chef_server_access_mode = '0', 
                    chef_server_host_name = '0', 
                    chef_server_key = '0', 
                    chef_server_port = '0', 
                    chef_server_url = '0', 
                    chef_server_username = '0', 
                    chef_skip_ssl = True, 
                    create_cert_using_pki = True, 
                    db_host_name = '0', 
                    db_isolation_level = '0', 
                    db_max_idle_conns = '0', 
                    db_max_open_conns = '0', 
                    db_name = '0', 
                    db_port = '0', 
                    db_pwd = '0', 
                    db_server_certificates = '0', 
                    db_server_name = '0', 
                    db_user_name = '0', 
                    dynamic_secret_id = 56, 
                    dynamic_secret_key = '0', 
                    dynamic_secret_name = '0', 
                    dynamic_secret_type = '0', 
                    eks_access_key_id = '0', 
                    eks_assume_role = '0', 
                    eks_cluster_ca_certificate = '0', 
                    eks_cluster_endpoint = '0', 
                    eks_cluster_name = '0', 
                    eks_region = '0', 
                    eks_secret_access_key = '0', 
                    enable_admin_rotation = True, 
                    failure_message = '0', 
                    fixed_user_only = '0', 
                    gke_cluster_ca_certificate = '0', 
                    gke_cluster_compute_zone = '0', 
                    gke_cluster_endpoint = '0', 
                    gke_cluster_name = '0', 
                    gke_project_id = '0', 
                    gke_service_account_key = '0', 
                    gke_service_account_name = '0', 
                    groups = '0', 
                    host_name = '0', 
                    host_port = '0', 
                    mongodb_db_name = '0', 
                    mongodb_roles = '0', 
                    mongodb_uri_connection = '0', 
                    mssql_creation_statements = '0', 
                    mssql_revocation_statements = '0', 
                    mysql_creation_statements = '0', 
                    postgres_creation_statements = '0', 
                    rabbitmq_server_password = '0', 
                    rabbitmq_server_uri = '0', 
                    rabbitmq_server_user = '0', 
                    rabbitmq_user_conf_permission = '0', 
                    rabbitmq_user_read_permission = '0', 
                    rabbitmq_user_tags = '0', 
                    rabbitmq_user_vhost = '0', 
                    rabbitmq_user_write_permission = '0', 
                    root_first_in_chain = True, 
                    should_stop = '0', 
                    signer_key_name = '0', 
                    store_private_key = True, 
                    user_principal_name = '0', 
                    user_ttl = '0', 
                    venafi_api_key = '0', 
                    venafi_zone = '0', )
            )
        else :
            return GatewayCreateProducerArtifactoryOutput(
        )

    def testGatewayCreateProducerArtifactoryOutput(self):
        """Test GatewayCreateProducerArtifactoryOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.target_type_detailes_input import TargetTypeDetailesInput  # noqa: E501
from akeyless.rest import ApiException

class TestTargetTypeDetailesInput(unittest.TestCase):
    """TargetTypeDetailesInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TargetTypeDetailesInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.target_type_detailes_input.TargetTypeDetailesInput()  # noqa: E501
        if include_optional :
            return TargetTypeDetailesInput(
                admin_name = '0', 
                admin_pwd = '0', 
                aws_access_key_id = '0', 
                aws_region = '0', 
                aws_secret_access_key = '0', 
                aws_session_token = '0', 
                db_host_name = '0', 
                db_port = '0', 
                db_pwd = '0', 
                db_user_name = '0', 
                host_name = '0', 
                host_port = '0', 
                ip = [
                    '0'
                    ], 
                mongodb_db_name = '0', 
                mongodb_uri_connection = '0', 
                port = '0', 
                rabbitmq_server_password = '0', 
                rabbitmq_server_uri = '0', 
                rabbitmq_server_user = '0', 
                url = '0'
            )
        else :
            return TargetTypeDetailesInput(
        )

    def testTargetTypeDetailesInput(self):
        """Test TargetTypeDetailesInput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.log_forwarding_config_part import LogForwardingConfigPart  # noqa: E501
from akeyless.rest import ApiException

class TestLogForwardingConfigPart(unittest.TestCase):
    """LogForwardingConfigPart unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LogForwardingConfigPart
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.log_forwarding_config_part.LogForwardingConfigPart()  # noqa: E501
        if include_optional :
            return LogForwardingConfigPart(
                elasticsearch_config = akeyless.models.elasticsearch_log_forwarding_config.ElasticsearchLogForwardingConfig(
                    elasticsearch_host = '0', 
                    elasticsearch_index = '0', 
                    elasticsearch_nodes = '0', ), 
                logan_enable = True, 
                logan_url = '0', 
                logstash_config = akeyless.models.logstash_log_forwarding_config.LogstashLogForwardingConfig(
                    logstash_dns = '0', 
                    logstash_protocol = '0', ), 
                logz_io_config = akeyless.models.logz_io_log_forwarding_config.LogzIoLogForwardingConfig(
                    target_logz_io_protocol = '0', 
                    target_logz_io_token = '0', ), 
                pull_interval_sec = '0', 
                splunk_config = akeyless.models.splunk_log_forwarding_config.SplunkLogForwardingConfig(
                    splunk_index = '0', 
                    splunk_source = '0', 
                    splunk_sourcetype = '0', 
                    splunk_token = '0', 
                    splunk_url = '0', ), 
                syslog_config = akeyless.models.syslog_log_forwarding_config.SyslogLogForwardingConfig(
                    syslog_host = '0', 
                    syslog_network = '0', 
                    syslog_target_tag = '0', ), 
                target_log_type = '0'
            )
        else :
            return LogForwardingConfigPart(
        )

    def testLogForwardingConfigPart(self):
        """Test LogForwardingConfigPart"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateSecretVal(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accessibility': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'key': 'str',
        'multiline': 'bool',
        'name': 'str',
        'new_version': 'bool',
        'password_manager_custom_field': 'dict(str, str)',
        'password_manager_inject_url': 'list[str]',
        'password_manager_password': 'str',
        'password_manager_username': 'str',
        'token': 'str',
        'uid_token': 'str',
        'value': 'str'
    }

    attribute_map = {
        'accessibility': 'accessibility',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'key': 'key',
        'multiline': 'multiline',
        'name': 'name',
        'new_version': 'new-version',
        'password_manager_custom_field': 'password-manager-custom-field',
        'password_manager_inject_url': 'password-manager-inject-url',
        'password_manager_password': 'password-manager-password',
        'password_manager_username': 'password-manager-username',
        'token': 'token',
        'uid_token': 'uid-token',
        'value': 'value'
    }

    def __init__(self, accessibility='regular', json=None, keep_prev_version=None, key=None, multiline=None, name=None, new_version=None, password_manager_custom_field=None, password_manager_inject_url=None, password_manager_password=None, password_manager_username=None, token=None, uid_token=None, value=None, local_vars_configuration=None):  # noqa: E501
        """UpdateSecretVal - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accessibility = None
        self._json = None
        self._keep_prev_version = None
        self._key = None
        self._multiline = None
        self._name = None
        self._new_version = None
        self._password_manager_custom_field = None
        self._password_manager_inject_url = None
        self._password_manager_password = None
        self._password_manager_username = None
        self._token = None
        self._uid_token = None
        self._value = None
        self.discriminator = None

        if accessibility is not None:
            self.accessibility = accessibility
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        if key is not None:
            self.key = key
        if multiline is not None:
            self.multiline = multiline
        self.name = name
        if new_version is not None:
            self.new_version = new_version
        if password_manager_custom_field is not None:
            self.password_manager_custom_field = password_manager_custom_field
        if password_manager_inject_url is not None:
            self.password_manager_inject_url = password_manager_inject_url
        if password_manager_password is not None:
            self.password_manager_password = password_manager_password
        if password_manager_username is not None:
            self.password_manager_username = password_manager_username
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        self.value = value

    @property
    def accessibility(self):
        """Gets the accessibility of this UpdateSecretVal.  # noqa: E501

        for personal password manager  # noqa: E501

        :return: The accessibility of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._accessibility

    @accessibility.setter
    def accessibility(self, accessibility):
        """Sets the accessibility of this UpdateSecretVal.

        for personal password manager  # noqa: E501

        :param accessibility: The accessibility of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._accessibility = accessibility

    @property
    def json(self):
        """Gets the json of this UpdateSecretVal.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateSecretVal.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateSecretVal.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateSecretVal.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateSecretVal.  # noqa: E501


        :return: The keep_prev_version of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateSecretVal.


        :param keep_prev_version: The keep_prev_version of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def key(self):
        """Gets the key of this UpdateSecretVal.  # noqa: E501

        The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this UpdateSecretVal.

        The name of a key that used to encrypt the secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def multiline(self):
        """Gets the multiline of this UpdateSecretVal.  # noqa: E501

        The provided value is a multiline value (separated by '\\n')  # noqa: E501

        :return: The multiline of this UpdateSecretVal.  # noqa: E501
        :rtype: bool
        """
        return self._multiline

    @multiline.setter
    def multiline(self, multiline):
        """Sets the multiline of this UpdateSecretVal.

        The provided value is a multiline value (separated by '\\n')  # noqa: E501

        :param multiline: The multiline of this UpdateSecretVal.  # noqa: E501
        :type: bool
        """

        self._multiline = multiline

    @property
    def name(self):
        """Gets the name of this UpdateSecretVal.  # noqa: E501

        Secret name  # noqa: E501

        :return: The name of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSecretVal.

        Secret name  # noqa: E501

        :param name: The name of this UpdateSecretVal.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_version(self):
        """Gets the new_version of this UpdateSecretVal.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The new_version of this UpdateSecretVal.  # noqa: E501
        :rtype: bool
        """
        return self._new_version

    @new_version.setter
    def new_version(self, new_version):
        """Sets the new_version of this UpdateSecretVal.

        Deprecated  # noqa: E501

        :param new_version: The new_version of this UpdateSecretVal.  # noqa: E501
        :type: bool
        """

        self._new_version = new_version

    @property
    def password_manager_custom_field(self):
        """Gets the password_manager_custom_field of this UpdateSecretVal.  # noqa: E501

        For Password Management use, additional fields  # noqa: E501

        :return: The password_manager_custom_field of this UpdateSecretVal.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._password_manager_custom_field

    @password_manager_custom_field.setter
    def password_manager_custom_field(self, password_manager_custom_field):
        """Sets the password_manager_custom_field of this UpdateSecretVal.

        For Password Management use, additional fields  # noqa: E501

        :param password_manager_custom_field: The password_manager_custom_field of this UpdateSecretVal.  # noqa: E501
        :type: dict(str, str)
        """

        self._password_manager_custom_field = password_manager_custom_field

    @property
    def password_manager_inject_url(self):
        """Gets the password_manager_inject_url of this UpdateSecretVal.  # noqa: E501

        For Password Management use, reflect the website context  # noqa: E501

        :return: The password_manager_inject_url of this UpdateSecretVal.  # noqa: E501
        :rtype: list[str]
        """
        return self._password_manager_inject_url

    @password_manager_inject_url.setter
    def password_manager_inject_url(self, password_manager_inject_url):
        """Sets the password_manager_inject_url of this UpdateSecretVal.

        For Password Management use, reflect the website context  # noqa: E501

        :param password_manager_inject_url: The password_manager_inject_url of this UpdateSecretVal.  # noqa: E501
        :type: list[str]
        """

        self._password_manager_inject_url = password_manager_inject_url

    @property
    def password_manager_password(self):
        """Gets the password_manager_password of this UpdateSecretVal.  # noqa: E501

        For Password Management use, additional fields  # noqa: E501

        :return: The password_manager_password of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._password_manager_password

    @password_manager_password.setter
    def password_manager_password(self, password_manager_password):
        """Sets the password_manager_password of this UpdateSecretVal.

        For Password Management use, additional fields  # noqa: E501

        :param password_manager_password: The password_manager_password of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._password_manager_password = password_manager_password

    @property
    def password_manager_username(self):
        """Gets the password_manager_username of this UpdateSecretVal.  # noqa: E501

        For Password Management use  # noqa: E501

        :return: The password_manager_username of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._password_manager_username

    @password_manager_username.setter
    def password_manager_username(self, password_manager_username):
        """Sets the password_manager_username of this UpdateSecretVal.

        For Password Management use  # noqa: E501

        :param password_manager_username: The password_manager_username of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._password_manager_username = password_manager_username

    @property
    def token(self):
        """Gets the token of this UpdateSecretVal.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateSecretVal.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateSecretVal.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateSecretVal.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateSecretVal.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def value(self):
        """Gets the value of this UpdateSecretVal.  # noqa: E501

        The new secret value  # noqa: E501

        :return: The value of this UpdateSecretVal.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this UpdateSecretVal.

        The new secret value  # noqa: E501

        :param value: The value of this UpdateSecretVal.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSecretVal):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSecretVal):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.gateway_migration_list_output import GatewayMigrationListOutput  # noqa: E501
from akeyless.rest import ApiException

class TestGatewayMigrationListOutput(unittest.TestCase):
    """GatewayMigrationListOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GatewayMigrationListOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.gateway_migration_list_output.GatewayMigrationListOutput()  # noqa: E501
        if include_optional :
            return GatewayMigrationListOutput(
                body = akeyless.models.migrations_config_part.MigrationsConfigPart(
                    aws_secrets_migrations = [
                        akeyless.models.aws_secrets_migration.AWSSecretsMigration(
                            general = akeyless.models.migration_general.MigrationGeneral(
                                id = '0', 
                                name = '0', 
                                prefix = '0', 
                                protection_key = '0', ), 
                            payload = akeyless.models.aws_payload.AWSPayload(
                                key = '0', 
                                region = '0', 
                                secret = '0', ), )
                        ], 
                    azure_kv_migrations = [
                        akeyless.models.azure_key_vault_migration.AzureKeyVaultMigration()
                        ], 
                    hashi_migrations = [
                        akeyless.models.hashi_migration.HashiMigration()
                        ], 
                    k8s_migrations = [
                        akeyless.models.k8_s_migration.K8SMigration()
                        ], )
            )
        else :
            return GatewayMigrationListOutput(
        )

    def testGatewayMigrationListOutput(self):
        """Test GatewayMigrationListOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class RotatedSecretDetailsInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'delete_previous_version_in_days': 'int',
        'gw_cluster_id': 'int',
        'last_rotation_error': 'str',
        'number_of_versions_to_save': 'int',
        'rotation_hour': 'int',
        'rotation_interval_min': 'bool',
        'rotation_statement': 'str',
        'rotator_creds_type': 'str',
        'rotator_status': 'str',
        'rotator_type': 'str'
    }

    attribute_map = {
        'delete_previous_version_in_days': 'delete_previous_version_in_days',
        'gw_cluster_id': 'gw_cluster_id',
        'last_rotation_error': 'last_rotation_error',
        'number_of_versions_to_save': 'number_of_versions_to_save',
        'rotation_hour': 'rotation_hour',
        'rotation_interval_min': 'rotation_interval_min',
        'rotation_statement': 'rotation_statement',
        'rotator_creds_type': 'rotator_creds_type',
        'rotator_status': 'rotator_status',
        'rotator_type': 'rotator_type'
    }

    def __init__(self, delete_previous_version_in_days=None, gw_cluster_id=None, last_rotation_error=None, number_of_versions_to_save=None, rotation_hour=None, rotation_interval_min=None, rotation_statement=None, rotator_creds_type=None, rotator_status=None, rotator_type=None, local_vars_configuration=None):  # noqa: E501
        """RotatedSecretDetailsInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._delete_previous_version_in_days = None
        self._gw_cluster_id = None
        self._last_rotation_error = None
        self._number_of_versions_to_save = None
        self._rotation_hour = None
        self._rotation_interval_min = None
        self._rotation_statement = None
        self._rotator_creds_type = None
        self._rotator_status = None
        self._rotator_type = None
        self.discriminator = None

        if delete_previous_version_in_days is not None:
            self.delete_previous_version_in_days = delete_previous_version_in_days
        if gw_cluster_id is not None:
            self.gw_cluster_id = gw_cluster_id
        if last_rotation_error is not None:
            self.last_rotation_error = last_rotation_error
        if number_of_versions_to_save is not None:
            self.number_of_versions_to_save = number_of_versions_to_save
        if rotation_hour is not None:
            self.rotation_hour = rotation_hour
        if rotation_interval_min is not None:
            self.rotation_interval_min = rotation_interval_min
        if rotation_statement is not None:
            self.rotation_statement = rotation_statement
        if rotator_creds_type is not None:
            self.rotator_creds_type = rotator_creds_type
        if rotator_status is not None:
            self.rotator_status = rotator_status
        if rotator_type is not None:
            self.rotator_type = rotator_type

    @property
    def delete_previous_version_in_days(self):
        """Gets the delete_previous_version_in_days of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The delete_previous_version_in_days of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: int
        """
        return self._delete_previous_version_in_days

    @delete_previous_version_in_days.setter
    def delete_previous_version_in_days(self, delete_previous_version_in_days):
        """Sets the delete_previous_version_in_days of this RotatedSecretDetailsInfo.


        :param delete_previous_version_in_days: The delete_previous_version_in_days of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: int
        """

        self._delete_previous_version_in_days = delete_previous_version_in_days

    @property
    def gw_cluster_id(self):
        """Gets the gw_cluster_id of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The gw_cluster_id of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: int
        """
        return self._gw_cluster_id

    @gw_cluster_id.setter
    def gw_cluster_id(self, gw_cluster_id):
        """Sets the gw_cluster_id of this RotatedSecretDetailsInfo.


        :param gw_cluster_id: The gw_cluster_id of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: int
        """

        self._gw_cluster_id = gw_cluster_id

    @property
    def last_rotation_error(self):
        """Gets the last_rotation_error of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The last_rotation_error of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_rotation_error

    @last_rotation_error.setter
    def last_rotation_error(self, last_rotation_error):
        """Sets the last_rotation_error of this RotatedSecretDetailsInfo.


        :param last_rotation_error: The last_rotation_error of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: str
        """

        self._last_rotation_error = last_rotation_error

    @property
    def number_of_versions_to_save(self):
        """Gets the number_of_versions_to_save of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The number_of_versions_to_save of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: int
        """
        return self._number_of_versions_to_save

    @number_of_versions_to_save.setter
    def number_of_versions_to_save(self, number_of_versions_to_save):
        """Sets the number_of_versions_to_save of this RotatedSecretDetailsInfo.


        :param number_of_versions_to_save: The number_of_versions_to_save of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: int
        """

        self._number_of_versions_to_save = number_of_versions_to_save

    @property
    def rotation_hour(self):
        """Gets the rotation_hour of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The rotation_hour of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: int
        """
        return self._rotation_hour

    @rotation_hour.setter
    def rotation_hour(self, rotation_hour):
        """Sets the rotation_hour of this RotatedSecretDetailsInfo.


        :param rotation_hour: The rotation_hour of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: int
        """

        self._rotation_hour = rotation_hour

    @property
    def rotation_interval_min(self):
        """Gets the rotation_interval_min of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The rotation_interval_min of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: bool
        """
        return self._rotation_interval_min

    @rotation_interval_min.setter
    def rotation_interval_min(self, rotation_interval_min):
        """Sets the rotation_interval_min of this RotatedSecretDetailsInfo.


        :param rotation_interval_min: The rotation_interval_min of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: bool
        """

        self._rotation_interval_min = rotation_interval_min

    @property
    def rotation_statement(self):
        """Gets the rotation_statement of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The rotation_statement of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._rotation_statement

    @rotation_statement.setter
    def rotation_statement(self, rotation_statement):
        """Sets the rotation_statement of this RotatedSecretDetailsInfo.


        :param rotation_statement: The rotation_statement of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: str
        """

        self._rotation_statement = rotation_statement

    @property
    def rotator_creds_type(self):
        """Gets the rotator_creds_type of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The rotator_creds_type of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._rotator_creds_type

    @rotator_creds_type.setter
    def rotator_creds_type(self, rotator_creds_type):
        """Sets the rotator_creds_type of this RotatedSecretDetailsInfo.


        :param rotator_creds_type: The rotator_creds_type of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: str
        """

        self._rotator_creds_type = rotator_creds_type

    @property
    def rotator_status(self):
        """Gets the rotator_status of this RotatedSecretDetailsInfo.  # noqa: E501

        RotationStatus defines types of rotation Status  # noqa: E501

        :return: The rotator_status of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._rotator_status

    @rotator_status.setter
    def rotator_status(self, rotator_status):
        """Sets the rotator_status of this RotatedSecretDetailsInfo.

        RotationStatus defines types of rotation Status  # noqa: E501

        :param rotator_status: The rotator_status of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: str
        """

        self._rotator_status = rotator_status

    @property
    def rotator_type(self):
        """Gets the rotator_type of this RotatedSecretDetailsInfo.  # noqa: E501


        :return: The rotator_type of this RotatedSecretDetailsInfo.  # noqa: E501
        :rtype: str
        """
        return self._rotator_type

    @rotator_type.setter
    def rotator_type(self, rotator_type):
        """Sets the rotator_type of this RotatedSecretDetailsInfo.


        :param rotator_type: The rotator_type of this RotatedSecretDetailsInfo.  # noqa: E501
        :type: str
        """

        self._rotator_type = rotator_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RotatedSecretDetailsInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RotatedSecretDetailsInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class CreateAzureTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'client_secret': 'str',
        'comment': 'str',
        'json': 'bool',
        'key': 'str',
        'name': 'str',
        'resource_group_name': 'str',
        'resource_name': 'str',
        'subscription_id': 'str',
        'tenant_id': 'str',
        'token': 'str',
        'uid_token': 'str',
        'use_gw_cloud_identity': 'bool'
    }

    attribute_map = {
        'client_id': 'client-id',
        'client_secret': 'client-secret',
        'comment': 'comment',
        'json': 'json',
        'key': 'key',
        'name': 'name',
        'resource_group_name': 'resource-group-name',
        'resource_name': 'resource-name',
        'subscription_id': 'subscription-id',
        'tenant_id': 'tenant-id',
        'token': 'token',
        'uid_token': 'uid-token',
        'use_gw_cloud_identity': 'use-gw-cloud-identity'
    }

    def __init__(self, client_id=None, client_secret=None, comment=None, json=None, key=None, name=None, resource_group_name=None, resource_name=None, subscription_id=None, tenant_id=None, token=None, uid_token=None, use_gw_cloud_identity=None, local_vars_configuration=None):  # noqa: E501
        """CreateAzureTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._client_secret = None
        self._comment = None
        self._json = None
        self._key = None
        self._name = None
        self._resource_group_name = None
        self._resource_name = None
        self._subscription_id = None
        self._tenant_id = None
        self._token = None
        self._uid_token = None
        self._use_gw_cloud_identity = None
        self.discriminator = None

        if client_id is not None:
            self.client_id = client_id
        if client_secret is not None:
            self.client_secret = client_secret
        if comment is not None:
            self.comment = comment
        if json is not None:
            self.json = json
        if key is not None:
            self.key = key
        self.name = name
        if resource_group_name is not None:
            self.resource_group_name = resource_group_name
        if resource_name is not None:
            self.resource_name = resource_name
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if use_gw_cloud_identity is not None:
            self.use_gw_cloud_identity = use_gw_cloud_identity

    @property
    def client_id(self):
        """Gets the client_id of this CreateAzureTarget.  # noqa: E501


        :return: The client_id of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this CreateAzureTarget.


        :param client_id: The client_id of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._client_id = client_id

    @property
    def client_secret(self):
        """Gets the client_secret of this CreateAzureTarget.  # noqa: E501


        :return: The client_secret of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """Sets the client_secret of this CreateAzureTarget.


        :param client_secret: The client_secret of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._client_secret = client_secret

    @property
    def comment(self):
        """Gets the comment of this CreateAzureTarget.  # noqa: E501

        Comment about the target  # noqa: E501

        :return: The comment of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateAzureTarget.

        Comment about the target  # noqa: E501

        :param comment: The comment of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def json(self):
        """Gets the json of this CreateAzureTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this CreateAzureTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this CreateAzureTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this CreateAzureTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key(self):
        """Gets the key of this CreateAzureTarget.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this CreateAzureTarget.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this CreateAzureTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateAzureTarget.

        Target name  # noqa: E501

        :param name: The name of this CreateAzureTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def resource_group_name(self):
        """Gets the resource_group_name of this CreateAzureTarget.  # noqa: E501

        The Resource Group name in your Azure subscription  # noqa: E501

        :return: The resource_group_name of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._resource_group_name

    @resource_group_name.setter
    def resource_group_name(self, resource_group_name):
        """Sets the resource_group_name of this CreateAzureTarget.

        The Resource Group name in your Azure subscription  # noqa: E501

        :param resource_group_name: The resource_group_name of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._resource_group_name = resource_group_name

    @property
    def resource_name(self):
        """Gets the resource_name of this CreateAzureTarget.  # noqa: E501

        The name of the relevant Resource  # noqa: E501

        :return: The resource_name of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """Sets the resource_name of this CreateAzureTarget.

        The name of the relevant Resource  # noqa: E501

        :param resource_name: The resource_name of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._resource_name = resource_name

    @property
    def subscription_id(self):
        """Gets the subscription_id of this CreateAzureTarget.  # noqa: E501

        Azure Subscription Id  # noqa: E501

        :return: The subscription_id of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this CreateAzureTarget.

        Azure Subscription Id  # noqa: E501

        :param subscription_id: The subscription_id of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this CreateAzureTarget.  # noqa: E501


        :return: The tenant_id of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this CreateAzureTarget.


        :param tenant_id: The tenant_id of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def token(self):
        """Gets the token of this CreateAzureTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this CreateAzureTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this CreateAzureTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this CreateAzureTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this CreateAzureTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this CreateAzureTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def use_gw_cloud_identity(self):
        """Gets the use_gw_cloud_identity of this CreateAzureTarget.  # noqa: E501


        :return: The use_gw_cloud_identity of this CreateAzureTarget.  # noqa: E501
        :rtype: bool
        """
        return self._use_gw_cloud_identity

    @use_gw_cloud_identity.setter
    def use_gw_cloud_identity(self, use_gw_cloud_identity):
        """Sets the use_gw_cloud_identity of this CreateAzureTarget.


        :param use_gw_cloud_identity: The use_gw_cloud_identity of this CreateAzureTarget.  # noqa: E501
        :type: bool
        """

        self._use_gw_cloud_identity = use_gw_cloud_identity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateAzureTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateAzureTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ActiveDirectoryPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_directory_target_id': 'int',
        'auto_rotate': 'bool',
        'auto_rotate_interval_in_days': 'int',
        'auto_rotate_rotation_hour': 'int',
        'computer_base_dn': 'str',
        'discover_local_users': 'bool',
        'domain_name': 'str',
        'domain_server_targets_path_template': 'str',
        'domain_users_rotated_secrets_path_template': 'str',
        'enable_rdp_sra': 'bool',
        'local_users_ignore_list': 'dict(str, bool)',
        'local_users_rotated_secrets_path_template': 'str',
        'ssh_port': 'str',
        'user_base_dn': 'str',
        'user_groups': 'list[str]'
    }

    attribute_map = {
        'active_directory_target_id': 'active_directory_target_id',
        'auto_rotate': 'auto_rotate',
        'auto_rotate_interval_in_days': 'auto_rotate_interval_in_days',
        'auto_rotate_rotation_hour': 'auto_rotate_rotation_hour',
        'computer_base_dn': 'computer_base_dn',
        'discover_local_users': 'discover_local_users',
        'domain_name': 'domain_name',
        'domain_server_targets_path_template': 'domain_server_targets_path_template',
        'domain_users_rotated_secrets_path_template': 'domain_users_rotated_secrets_path_template',
        'enable_rdp_sra': 'enable_rdp_sra',
        'local_users_ignore_list': 'local_users_ignore_list',
        'local_users_rotated_secrets_path_template': 'local_users_rotated_secrets_path_template',
        'ssh_port': 'ssh_port',
        'user_base_dn': 'user_base_dn',
        'user_groups': 'user_groups'
    }

    def __init__(self, active_directory_target_id=None, auto_rotate=None, auto_rotate_interval_in_days=None, auto_rotate_rotation_hour=None, computer_base_dn=None, discover_local_users=None, domain_name=None, domain_server_targets_path_template=None, domain_users_rotated_secrets_path_template=None, enable_rdp_sra=None, local_users_ignore_list=None, local_users_rotated_secrets_path_template=None, ssh_port=None, user_base_dn=None, user_groups=None, local_vars_configuration=None):  # noqa: E501
        """ActiveDirectoryPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_directory_target_id = None
        self._auto_rotate = None
        self._auto_rotate_interval_in_days = None
        self._auto_rotate_rotation_hour = None
        self._computer_base_dn = None
        self._discover_local_users = None
        self._domain_name = None
        self._domain_server_targets_path_template = None
        self._domain_users_rotated_secrets_path_template = None
        self._enable_rdp_sra = None
        self._local_users_ignore_list = None
        self._local_users_rotated_secrets_path_template = None
        self._ssh_port = None
        self._user_base_dn = None
        self._user_groups = None
        self.discriminator = None

        if active_directory_target_id is not None:
            self.active_directory_target_id = active_directory_target_id
        if auto_rotate is not None:
            self.auto_rotate = auto_rotate
        if auto_rotate_interval_in_days is not None:
            self.auto_rotate_interval_in_days = auto_rotate_interval_in_days
        if auto_rotate_rotation_hour is not None:
            self.auto_rotate_rotation_hour = auto_rotate_rotation_hour
        if computer_base_dn is not None:
            self.computer_base_dn = computer_base_dn
        if discover_local_users is not None:
            self.discover_local_users = discover_local_users
        if domain_name is not None:
            self.domain_name = domain_name
        if domain_server_targets_path_template is not None:
            self.domain_server_targets_path_template = domain_server_targets_path_template
        if domain_users_rotated_secrets_path_template is not None:
            self.domain_users_rotated_secrets_path_template = domain_users_rotated_secrets_path_template
        if enable_rdp_sra is not None:
            self.enable_rdp_sra = enable_rdp_sra
        if local_users_ignore_list is not None:
            self.local_users_ignore_list = local_users_ignore_list
        if local_users_rotated_secrets_path_template is not None:
            self.local_users_rotated_secrets_path_template = local_users_rotated_secrets_path_template
        if ssh_port is not None:
            self.ssh_port = ssh_port
        if user_base_dn is not None:
            self.user_base_dn = user_base_dn
        if user_groups is not None:
            self.user_groups = user_groups

    @property
    def active_directory_target_id(self):
        """Gets the active_directory_target_id of this ActiveDirectoryPayload.  # noqa: E501


        :return: The active_directory_target_id of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: int
        """
        return self._active_directory_target_id

    @active_directory_target_id.setter
    def active_directory_target_id(self, active_directory_target_id):
        """Sets the active_directory_target_id of this ActiveDirectoryPayload.


        :param active_directory_target_id: The active_directory_target_id of this ActiveDirectoryPayload.  # noqa: E501
        :type: int
        """

        self._active_directory_target_id = active_directory_target_id

    @property
    def auto_rotate(self):
        """Gets the auto_rotate of this ActiveDirectoryPayload.  # noqa: E501


        :return: The auto_rotate of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: bool
        """
        return self._auto_rotate

    @auto_rotate.setter
    def auto_rotate(self, auto_rotate):
        """Sets the auto_rotate of this ActiveDirectoryPayload.


        :param auto_rotate: The auto_rotate of this ActiveDirectoryPayload.  # noqa: E501
        :type: bool
        """

        self._auto_rotate = auto_rotate

    @property
    def auto_rotate_interval_in_days(self):
        """Gets the auto_rotate_interval_in_days of this ActiveDirectoryPayload.  # noqa: E501


        :return: The auto_rotate_interval_in_days of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: int
        """
        return self._auto_rotate_interval_in_days

    @auto_rotate_interval_in_days.setter
    def auto_rotate_interval_in_days(self, auto_rotate_interval_in_days):
        """Sets the auto_rotate_interval_in_days of this ActiveDirectoryPayload.


        :param auto_rotate_interval_in_days: The auto_rotate_interval_in_days of this ActiveDirectoryPayload.  # noqa: E501
        :type: int
        """

        self._auto_rotate_interval_in_days = auto_rotate_interval_in_days

    @property
    def auto_rotate_rotation_hour(self):
        """Gets the auto_rotate_rotation_hour of this ActiveDirectoryPayload.  # noqa: E501


        :return: The auto_rotate_rotation_hour of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: int
        """
        return self._auto_rotate_rotation_hour

    @auto_rotate_rotation_hour.setter
    def auto_rotate_rotation_hour(self, auto_rotate_rotation_hour):
        """Sets the auto_rotate_rotation_hour of this ActiveDirectoryPayload.


        :param auto_rotate_rotation_hour: The auto_rotate_rotation_hour of this ActiveDirectoryPayload.  # noqa: E501
        :type: int
        """

        self._auto_rotate_rotation_hour = auto_rotate_rotation_hour

    @property
    def computer_base_dn(self):
        """Gets the computer_base_dn of this ActiveDirectoryPayload.  # noqa: E501


        :return: The computer_base_dn of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._computer_base_dn

    @computer_base_dn.setter
    def computer_base_dn(self, computer_base_dn):
        """Sets the computer_base_dn of this ActiveDirectoryPayload.


        :param computer_base_dn: The computer_base_dn of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._computer_base_dn = computer_base_dn

    @property
    def discover_local_users(self):
        """Gets the discover_local_users of this ActiveDirectoryPayload.  # noqa: E501


        :return: The discover_local_users of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: bool
        """
        return self._discover_local_users

    @discover_local_users.setter
    def discover_local_users(self, discover_local_users):
        """Sets the discover_local_users of this ActiveDirectoryPayload.


        :param discover_local_users: The discover_local_users of this ActiveDirectoryPayload.  # noqa: E501
        :type: bool
        """

        self._discover_local_users = discover_local_users

    @property
    def domain_name(self):
        """Gets the domain_name of this ActiveDirectoryPayload.  # noqa: E501


        :return: The domain_name of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this ActiveDirectoryPayload.


        :param domain_name: The domain_name of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._domain_name = domain_name

    @property
    def domain_server_targets_path_template(self):
        """Gets the domain_server_targets_path_template of this ActiveDirectoryPayload.  # noqa: E501


        :return: The domain_server_targets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._domain_server_targets_path_template

    @domain_server_targets_path_template.setter
    def domain_server_targets_path_template(self, domain_server_targets_path_template):
        """Sets the domain_server_targets_path_template of this ActiveDirectoryPayload.


        :param domain_server_targets_path_template: The domain_server_targets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._domain_server_targets_path_template = domain_server_targets_path_template

    @property
    def domain_users_rotated_secrets_path_template(self):
        """Gets the domain_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501


        :return: The domain_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._domain_users_rotated_secrets_path_template

    @domain_users_rotated_secrets_path_template.setter
    def domain_users_rotated_secrets_path_template(self, domain_users_rotated_secrets_path_template):
        """Sets the domain_users_rotated_secrets_path_template of this ActiveDirectoryPayload.


        :param domain_users_rotated_secrets_path_template: The domain_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._domain_users_rotated_secrets_path_template = domain_users_rotated_secrets_path_template

    @property
    def enable_rdp_sra(self):
        """Gets the enable_rdp_sra of this ActiveDirectoryPayload.  # noqa: E501


        :return: The enable_rdp_sra of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: bool
        """
        return self._enable_rdp_sra

    @enable_rdp_sra.setter
    def enable_rdp_sra(self, enable_rdp_sra):
        """Sets the enable_rdp_sra of this ActiveDirectoryPayload.


        :param enable_rdp_sra: The enable_rdp_sra of this ActiveDirectoryPayload.  # noqa: E501
        :type: bool
        """

        self._enable_rdp_sra = enable_rdp_sra

    @property
    def local_users_ignore_list(self):
        """Gets the local_users_ignore_list of this ActiveDirectoryPayload.  # noqa: E501


        :return: The local_users_ignore_list of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: dict(str, bool)
        """
        return self._local_users_ignore_list

    @local_users_ignore_list.setter
    def local_users_ignore_list(self, local_users_ignore_list):
        """Sets the local_users_ignore_list of this ActiveDirectoryPayload.


        :param local_users_ignore_list: The local_users_ignore_list of this ActiveDirectoryPayload.  # noqa: E501
        :type: dict(str, bool)
        """

        self._local_users_ignore_list = local_users_ignore_list

    @property
    def local_users_rotated_secrets_path_template(self):
        """Gets the local_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501


        :return: The local_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._local_users_rotated_secrets_path_template

    @local_users_rotated_secrets_path_template.setter
    def local_users_rotated_secrets_path_template(self, local_users_rotated_secrets_path_template):
        """Sets the local_users_rotated_secrets_path_template of this ActiveDirectoryPayload.


        :param local_users_rotated_secrets_path_template: The local_users_rotated_secrets_path_template of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._local_users_rotated_secrets_path_template = local_users_rotated_secrets_path_template

    @property
    def ssh_port(self):
        """Gets the ssh_port of this ActiveDirectoryPayload.  # noqa: E501


        :return: The ssh_port of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._ssh_port

    @ssh_port.setter
    def ssh_port(self, ssh_port):
        """Sets the ssh_port of this ActiveDirectoryPayload.


        :param ssh_port: The ssh_port of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._ssh_port = ssh_port

    @property
    def user_base_dn(self):
        """Gets the user_base_dn of this ActiveDirectoryPayload.  # noqa: E501


        :return: The user_base_dn of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_base_dn

    @user_base_dn.setter
    def user_base_dn(self, user_base_dn):
        """Sets the user_base_dn of this ActiveDirectoryPayload.


        :param user_base_dn: The user_base_dn of this ActiveDirectoryPayload.  # noqa: E501
        :type: str
        """

        self._user_base_dn = user_base_dn

    @property
    def user_groups(self):
        """Gets the user_groups of this ActiveDirectoryPayload.  # noqa: E501


        :return: The user_groups of this ActiveDirectoryPayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._user_groups

    @user_groups.setter
    def user_groups(self, user_groups):
        """Sets the user_groups of this ActiveDirectoryPayload.


        :param user_groups: The user_groups of this ActiveDirectoryPayload.  # noqa: E501
        :type: list[str]
        """

        self._user_groups = user_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActiveDirectoryPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActiveDirectoryPayload):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GetAccountSettingsCommandOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'address': 'CustomerFullAddress',
        'company_name': 'str',
        'email': 'str',
        'general_settings': 'AccountGeneralSettings',
        'object_version_settings': 'AccountObjectVersionSettingsOutput',
        'phone': 'str',
        'secret_management': 'SmInfo',
        'secure_remote_access': 'SraInfo',
        'system_access_creds_settings': 'SystemAccessCredsSettings'
    }

    attribute_map = {
        'account_id': 'account_id',
        'address': 'address',
        'company_name': 'company_name',
        'email': 'email',
        'general_settings': 'general_settings',
        'object_version_settings': 'object_version_settings',
        'phone': 'phone',
        'secret_management': 'secret_management',
        'secure_remote_access': 'secure_remote_access',
        'system_access_creds_settings': 'system_access_creds_settings'
    }

    def __init__(self, account_id=None, address=None, company_name=None, email=None, general_settings=None, object_version_settings=None, phone=None, secret_management=None, secure_remote_access=None, system_access_creds_settings=None, local_vars_configuration=None):  # noqa: E501
        """GetAccountSettingsCommandOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._address = None
        self._company_name = None
        self._email = None
        self._general_settings = None
        self._object_version_settings = None
        self._phone = None
        self._secret_management = None
        self._secure_remote_access = None
        self._system_access_creds_settings = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if address is not None:
            self.address = address
        if company_name is not None:
            self.company_name = company_name
        if email is not None:
            self.email = email
        if general_settings is not None:
            self.general_settings = general_settings
        if object_version_settings is not None:
            self.object_version_settings = object_version_settings
        if phone is not None:
            self.phone = phone
        if secret_management is not None:
            self.secret_management = secret_management
        if secure_remote_access is not None:
            self.secure_remote_access = secure_remote_access
        if system_access_creds_settings is not None:
            self.system_access_creds_settings = system_access_creds_settings

    @property
    def account_id(self):
        """Gets the account_id of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The account_id of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this GetAccountSettingsCommandOutput.


        :param account_id: The account_id of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def address(self):
        """Gets the address of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The address of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: CustomerFullAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this GetAccountSettingsCommandOutput.


        :param address: The address of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: CustomerFullAddress
        """

        self._address = address

    @property
    def company_name(self):
        """Gets the company_name of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The company_name of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this GetAccountSettingsCommandOutput.


        :param company_name: The company_name of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def email(self):
        """Gets the email of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The email of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetAccountSettingsCommandOutput.


        :param email: The email of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def general_settings(self):
        """Gets the general_settings of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The general_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: AccountGeneralSettings
        """
        return self._general_settings

    @general_settings.setter
    def general_settings(self, general_settings):
        """Sets the general_settings of this GetAccountSettingsCommandOutput.


        :param general_settings: The general_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: AccountGeneralSettings
        """

        self._general_settings = general_settings

    @property
    def object_version_settings(self):
        """Gets the object_version_settings of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The object_version_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: AccountObjectVersionSettingsOutput
        """
        return self._object_version_settings

    @object_version_settings.setter
    def object_version_settings(self, object_version_settings):
        """Sets the object_version_settings of this GetAccountSettingsCommandOutput.


        :param object_version_settings: The object_version_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: AccountObjectVersionSettingsOutput
        """

        self._object_version_settings = object_version_settings

    @property
    def phone(self):
        """Gets the phone of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The phone of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this GetAccountSettingsCommandOutput.


        :param phone: The phone of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def secret_management(self):
        """Gets the secret_management of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The secret_management of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: SmInfo
        """
        return self._secret_management

    @secret_management.setter
    def secret_management(self, secret_management):
        """Sets the secret_management of this GetAccountSettingsCommandOutput.


        :param secret_management: The secret_management of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: SmInfo
        """

        self._secret_management = secret_management

    @property
    def secure_remote_access(self):
        """Gets the secure_remote_access of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The secure_remote_access of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: SraInfo
        """
        return self._secure_remote_access

    @secure_remote_access.setter
    def secure_remote_access(self, secure_remote_access):
        """Sets the secure_remote_access of this GetAccountSettingsCommandOutput.


        :param secure_remote_access: The secure_remote_access of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: SraInfo
        """

        self._secure_remote_access = secure_remote_access

    @property
    def system_access_creds_settings(self):
        """Gets the system_access_creds_settings of this GetAccountSettingsCommandOutput.  # noqa: E501


        :return: The system_access_creds_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :rtype: SystemAccessCredsSettings
        """
        return self._system_access_creds_settings

    @system_access_creds_settings.setter
    def system_access_creds_settings(self, system_access_creds_settings):
        """Sets the system_access_creds_settings of this GetAccountSettingsCommandOutput.


        :param system_access_creds_settings: The system_access_creds_settings of this GetAccountSettingsCommandOutput.  # noqa: E501
        :type: SystemAccessCredsSettings
        """

        self._system_access_creds_settings = system_access_creds_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAccountSettingsCommandOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetAccountSettingsCommandOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateSSHTargetDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'name': 'str',
        'new_version': 'bool',
        'port': 'str',
        'private_key': 'str',
        'private_key_password': 'str',
        'protection_key': 'str',
        'ssh_password': 'str',
        'ssh_username': 'str',
        'token': 'str',
        'uid_token': 'str'
    }

    attribute_map = {
        'host': 'host',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'name': 'name',
        'new_version': 'new-version',
        'port': 'port',
        'private_key': 'private-key',
        'private_key_password': 'private-key-password',
        'protection_key': 'protection_key',
        'ssh_password': 'ssh-password',
        'ssh_username': 'ssh-username',
        'token': 'token',
        'uid_token': 'uid-token'
    }

    def __init__(self, host=None, json=None, keep_prev_version=None, name=None, new_version=None, port=None, private_key=None, private_key_password=None, protection_key=None, ssh_password=None, ssh_username=None, token=None, uid_token=None, local_vars_configuration=None):  # noqa: E501
        """UpdateSSHTargetDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._json = None
        self._keep_prev_version = None
        self._name = None
        self._new_version = None
        self._port = None
        self._private_key = None
        self._private_key_password = None
        self._protection_key = None
        self._ssh_password = None
        self._ssh_username = None
        self._token = None
        self._uid_token = None
        self.discriminator = None

        if host is not None:
            self.host = host
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        self.name = name
        if new_version is not None:
            self.new_version = new_version
        if port is not None:
            self.port = port
        if private_key is not None:
            self.private_key = private_key
        if private_key_password is not None:
            self.private_key_password = private_key_password
        if protection_key is not None:
            self.protection_key = protection_key
        if ssh_password is not None:
            self.ssh_password = ssh_password
        if ssh_username is not None:
            self.ssh_username = ssh_username
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token

    @property
    def host(self):
        """Gets the host of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The host of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this UpdateSSHTargetDetails.


        :param host: The host of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def json(self):
        """Gets the json of this UpdateSSHTargetDetails.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateSSHTargetDetails.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateSSHTargetDetails.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The keep_prev_version of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateSSHTargetDetails.


        :param keep_prev_version: The keep_prev_version of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def name(self):
        """Gets the name of this UpdateSSHTargetDetails.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateSSHTargetDetails.

        Target name  # noqa: E501

        :param name: The name of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_version(self):
        """Gets the new_version of this UpdateSSHTargetDetails.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The new_version of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: bool
        """
        return self._new_version

    @new_version.setter
    def new_version(self, new_version):
        """Sets the new_version of this UpdateSSHTargetDetails.

        Deprecated  # noqa: E501

        :param new_version: The new_version of this UpdateSSHTargetDetails.  # noqa: E501
        :type: bool
        """

        self._new_version = new_version

    @property
    def port(self):
        """Gets the port of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The port of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this UpdateSSHTargetDetails.


        :param port: The port of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._port = port

    @property
    def private_key(self):
        """Gets the private_key of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The private_key of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this UpdateSSHTargetDetails.


        :param private_key: The private_key of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._private_key = private_key

    @property
    def private_key_password(self):
        """Gets the private_key_password of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The private_key_password of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._private_key_password

    @private_key_password.setter
    def private_key_password(self, private_key_password):
        """Sets the private_key_password of this UpdateSSHTargetDetails.


        :param private_key_password: The private_key_password of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._private_key_password = private_key_password

    @property
    def protection_key(self):
        """Gets the protection_key of this UpdateSSHTargetDetails.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The protection_key of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this UpdateSSHTargetDetails.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param protection_key: The protection_key of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def ssh_password(self):
        """Gets the ssh_password of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The ssh_password of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._ssh_password

    @ssh_password.setter
    def ssh_password(self, ssh_password):
        """Sets the ssh_password of this UpdateSSHTargetDetails.


        :param ssh_password: The ssh_password of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._ssh_password = ssh_password

    @property
    def ssh_username(self):
        """Gets the ssh_username of this UpdateSSHTargetDetails.  # noqa: E501


        :return: The ssh_username of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._ssh_username

    @ssh_username.setter
    def ssh_username(self, ssh_username):
        """Sets the ssh_username of this UpdateSSHTargetDetails.


        :param ssh_username: The ssh_username of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._ssh_username = ssh_username

    @property
    def token(self):
        """Gets the token of this UpdateSSHTargetDetails.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateSSHTargetDetails.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateSSHTargetDetails.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateSSHTargetDetails.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateSSHTargetDetails.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateSSHTargetDetails.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateSSHTargetDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateSSHTargetDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class UpdateGithubTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'comment': 'str',
        'github_app_id': 'int',
        'github_app_private_key': 'str',
        'github_base_url': 'str',
        'json': 'bool',
        'keep_prev_version': 'str',
        'key': 'str',
        'name': 'str',
        'new_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'update_version': 'bool'
    }

    attribute_map = {
        'comment': 'comment',
        'github_app_id': 'github-app-id',
        'github_app_private_key': 'github-app-private-key',
        'github_base_url': 'github-base-url',
        'json': 'json',
        'keep_prev_version': 'keep-prev-version',
        'key': 'key',
        'name': 'name',
        'new_name': 'new-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'update_version': 'update-version'
    }

    def __init__(self, comment=None, github_app_id=None, github_app_private_key=None, github_base_url=None, json=None, keep_prev_version=None, key=None, name=None, new_name=None, token=None, uid_token=None, update_version=None, local_vars_configuration=None):  # noqa: E501
        """UpdateGithubTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._comment = None
        self._github_app_id = None
        self._github_app_private_key = None
        self._github_base_url = None
        self._json = None
        self._keep_prev_version = None
        self._key = None
        self._name = None
        self._new_name = None
        self._token = None
        self._uid_token = None
        self._update_version = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if github_app_id is not None:
            self.github_app_id = github_app_id
        if github_app_private_key is not None:
            self.github_app_private_key = github_app_private_key
        if github_base_url is not None:
            self.github_base_url = github_base_url
        if json is not None:
            self.json = json
        if keep_prev_version is not None:
            self.keep_prev_version = keep_prev_version
        if key is not None:
            self.key = key
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if update_version is not None:
            self.update_version = update_version

    @property
    def comment(self):
        """Gets the comment of this UpdateGithubTarget.  # noqa: E501

        Comment about the target  # noqa: E501

        :return: The comment of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UpdateGithubTarget.

        Comment about the target  # noqa: E501

        :param comment: The comment of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def github_app_id(self):
        """Gets the github_app_id of this UpdateGithubTarget.  # noqa: E501

        Github app id  # noqa: E501

        :return: The github_app_id of this UpdateGithubTarget.  # noqa: E501
        :rtype: int
        """
        return self._github_app_id

    @github_app_id.setter
    def github_app_id(self, github_app_id):
        """Sets the github_app_id of this UpdateGithubTarget.

        Github app id  # noqa: E501

        :param github_app_id: The github_app_id of this UpdateGithubTarget.  # noqa: E501
        :type: int
        """

        self._github_app_id = github_app_id

    @property
    def github_app_private_key(self):
        """Gets the github_app_private_key of this UpdateGithubTarget.  # noqa: E501

        App private key  # noqa: E501

        :return: The github_app_private_key of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._github_app_private_key

    @github_app_private_key.setter
    def github_app_private_key(self, github_app_private_key):
        """Sets the github_app_private_key of this UpdateGithubTarget.

        App private key  # noqa: E501

        :param github_app_private_key: The github_app_private_key of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._github_app_private_key = github_app_private_key

    @property
    def github_base_url(self):
        """Gets the github_base_url of this UpdateGithubTarget.  # noqa: E501

        Base URL  # noqa: E501

        :return: The github_base_url of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._github_base_url

    @github_base_url.setter
    def github_base_url(self, github_base_url):
        """Sets the github_base_url of this UpdateGithubTarget.

        Base URL  # noqa: E501

        :param github_base_url: The github_base_url of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._github_base_url = github_base_url

    @property
    def json(self):
        """Gets the json of this UpdateGithubTarget.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this UpdateGithubTarget.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this UpdateGithubTarget.

        Set output format to JSON  # noqa: E501

        :param json: The json of this UpdateGithubTarget.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def keep_prev_version(self):
        """Gets the keep_prev_version of this UpdateGithubTarget.  # noqa: E501


        :return: The keep_prev_version of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._keep_prev_version

    @keep_prev_version.setter
    def keep_prev_version(self, keep_prev_version):
        """Sets the keep_prev_version of this UpdateGithubTarget.


        :param keep_prev_version: The keep_prev_version of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._keep_prev_version = keep_prev_version

    @property
    def key(self):
        """Gets the key of this UpdateGithubTarget.  # noqa: E501

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :return: The key of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this UpdateGithubTarget.

        The name of a key that used to encrypt the target secret value (if empty, the account default protectionKey key will be used)  # noqa: E501

        :param key: The key of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def name(self):
        """Gets the name of this UpdateGithubTarget.  # noqa: E501

        Target name  # noqa: E501

        :return: The name of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateGithubTarget.

        Target name  # noqa: E501

        :param name: The name of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this UpdateGithubTarget.  # noqa: E501

        New target name  # noqa: E501

        :return: The new_name of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this UpdateGithubTarget.

        New target name  # noqa: E501

        :param new_name: The new_name of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def token(self):
        """Gets the token of this UpdateGithubTarget.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this UpdateGithubTarget.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this UpdateGithubTarget.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this UpdateGithubTarget.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this UpdateGithubTarget.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this UpdateGithubTarget.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def update_version(self):
        """Gets the update_version of this UpdateGithubTarget.  # noqa: E501

        Deprecated  # noqa: E501

        :return: The update_version of this UpdateGithubTarget.  # noqa: E501
        :rtype: bool
        """
        return self._update_version

    @update_version.setter
    def update_version(self, update_version):
        """Sets the update_version of this UpdateGithubTarget.

        Deprecated  # noqa: E501

        :param update_version: The update_version of this UpdateGithubTarget.  # noqa: E501
        :type: bool
        """

        self._update_version = update_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateGithubTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateGithubTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.get_account_settings_command_output import GetAccountSettingsCommandOutput  # noqa: E501
from akeyless.rest import ApiException

class TestGetAccountSettingsCommandOutput(unittest.TestCase):
    """GetAccountSettingsCommandOutput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetAccountSettingsCommandOutput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.get_account_settings_command_output.GetAccountSettingsCommandOutput()  # noqa: E501
        if include_optional :
            return GetAccountSettingsCommandOutput(
                account_id = '0', 
                address = akeyless.models.customer_full_address.CustomerFullAddress(
                    city = '0', 
                    country = '0', 
                    postal_code = '0', 
                    street = '0', ), 
                company_name = '0', 
                email = '0', 
                phone = '0', 
                secret_management = akeyless.models.sm_info.SmInfo(
                    package = '0', 
                    tier = '0', ), 
                secure_remote_access = akeyless.models.sra_info.SraInfo(
                    package = '0', 
                    tier = '0', 
                    user_type = '0', ), 
                system_access_creds_settings = akeyless.models.system_access_creds_settings.SystemAccessCredsSettings(
                    jwt_ttl_default = 56, 
                    jwt_ttl_maximum = 56, 
                    jwt_ttl_minimum = 56, )
            )
        else :
            return GetAccountSettingsCommandOutput(
        )

    def testGetAccountSettingsCommandOutput(self):
        """Test GetAccountSettingsCommandOutput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class NotiForwarder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_permissions': 'list[str]',
        'comment': 'str',
        'creation_date': 'datetime',
        'endpoint': 'str',
        'event_types': 'list[str]',
        'gateway_cluster_id': 'int',
        'is_enabled': 'bool',
        'last_version': 'int',
        'modification_date': 'datetime',
        'noti_forwarder_id': 'int',
        'noti_forwarder_name': 'str',
        'noti_forwarder_type': 'str',
        'noti_forwarder_versions': 'list[ItemVersion]',
        'paths': 'list[str]',
        'protection_key': 'str',
        'runner_type': 'str',
        'timespan_in_seconds': 'int',
        'to_emails': 'list[EmailEntry]',
        'username': 'str',
        'with_customer_fragment': 'bool'
    }

    attribute_map = {
        'client_permissions': 'client_permissions',
        'comment': 'comment',
        'creation_date': 'creation_date',
        'endpoint': 'endpoint',
        'event_types': 'event_types',
        'gateway_cluster_id': 'gateway_cluster_id',
        'is_enabled': 'is_enabled',
        'last_version': 'last_version',
        'modification_date': 'modification_date',
        'noti_forwarder_id': 'noti_forwarder_id',
        'noti_forwarder_name': 'noti_forwarder_name',
        'noti_forwarder_type': 'noti_forwarder_type',
        'noti_forwarder_versions': 'noti_forwarder_versions',
        'paths': 'paths',
        'protection_key': 'protection_key',
        'runner_type': 'runner_type',
        'timespan_in_seconds': 'timespan_in_seconds',
        'to_emails': 'to_emails',
        'username': 'username',
        'with_customer_fragment': 'with_customer_fragment'
    }

    def __init__(self, client_permissions=None, comment=None, creation_date=None, endpoint=None, event_types=None, gateway_cluster_id=None, is_enabled=None, last_version=None, modification_date=None, noti_forwarder_id=None, noti_forwarder_name=None, noti_forwarder_type=None, noti_forwarder_versions=None, paths=None, protection_key=None, runner_type=None, timespan_in_seconds=None, to_emails=None, username=None, with_customer_fragment=None, local_vars_configuration=None):  # noqa: E501
        """NotiForwarder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_permissions = None
        self._comment = None
        self._creation_date = None
        self._endpoint = None
        self._event_types = None
        self._gateway_cluster_id = None
        self._is_enabled = None
        self._last_version = None
        self._modification_date = None
        self._noti_forwarder_id = None
        self._noti_forwarder_name = None
        self._noti_forwarder_type = None
        self._noti_forwarder_versions = None
        self._paths = None
        self._protection_key = None
        self._runner_type = None
        self._timespan_in_seconds = None
        self._to_emails = None
        self._username = None
        self._with_customer_fragment = None
        self.discriminator = None

        if client_permissions is not None:
            self.client_permissions = client_permissions
        if comment is not None:
            self.comment = comment
        if creation_date is not None:
            self.creation_date = creation_date
        if endpoint is not None:
            self.endpoint = endpoint
        if event_types is not None:
            self.event_types = event_types
        if gateway_cluster_id is not None:
            self.gateway_cluster_id = gateway_cluster_id
        if is_enabled is not None:
            self.is_enabled = is_enabled
        if last_version is not None:
            self.last_version = last_version
        if modification_date is not None:
            self.modification_date = modification_date
        if noti_forwarder_id is not None:
            self.noti_forwarder_id = noti_forwarder_id
        if noti_forwarder_name is not None:
            self.noti_forwarder_name = noti_forwarder_name
        if noti_forwarder_type is not None:
            self.noti_forwarder_type = noti_forwarder_type
        if noti_forwarder_versions is not None:
            self.noti_forwarder_versions = noti_forwarder_versions
        if paths is not None:
            self.paths = paths
        if protection_key is not None:
            self.protection_key = protection_key
        if runner_type is not None:
            self.runner_type = runner_type
        if timespan_in_seconds is not None:
            self.timespan_in_seconds = timespan_in_seconds
        if to_emails is not None:
            self.to_emails = to_emails
        if username is not None:
            self.username = username
        if with_customer_fragment is not None:
            self.with_customer_fragment = with_customer_fragment

    @property
    def client_permissions(self):
        """Gets the client_permissions of this NotiForwarder.  # noqa: E501


        :return: The client_permissions of this NotiForwarder.  # noqa: E501
        :rtype: list[str]
        """
        return self._client_permissions

    @client_permissions.setter
    def client_permissions(self, client_permissions):
        """Sets the client_permissions of this NotiForwarder.


        :param client_permissions: The client_permissions of this NotiForwarder.  # noqa: E501
        :type: list[str]
        """

        self._client_permissions = client_permissions

    @property
    def comment(self):
        """Gets the comment of this NotiForwarder.  # noqa: E501


        :return: The comment of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this NotiForwarder.


        :param comment: The comment of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def creation_date(self):
        """Gets the creation_date of this NotiForwarder.  # noqa: E501


        :return: The creation_date of this NotiForwarder.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this NotiForwarder.


        :param creation_date: The creation_date of this NotiForwarder.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def endpoint(self):
        """Gets the endpoint of this NotiForwarder.  # noqa: E501


        :return: The endpoint of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this NotiForwarder.


        :param endpoint: The endpoint of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def event_types(self):
        """Gets the event_types of this NotiForwarder.  # noqa: E501


        :return: The event_types of this NotiForwarder.  # noqa: E501
        :rtype: list[str]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this NotiForwarder.


        :param event_types: The event_types of this NotiForwarder.  # noqa: E501
        :type: list[str]
        """

        self._event_types = event_types

    @property
    def gateway_cluster_id(self):
        """Gets the gateway_cluster_id of this NotiForwarder.  # noqa: E501


        :return: The gateway_cluster_id of this NotiForwarder.  # noqa: E501
        :rtype: int
        """
        return self._gateway_cluster_id

    @gateway_cluster_id.setter
    def gateway_cluster_id(self, gateway_cluster_id):
        """Sets the gateway_cluster_id of this NotiForwarder.


        :param gateway_cluster_id: The gateway_cluster_id of this NotiForwarder.  # noqa: E501
        :type: int
        """

        self._gateway_cluster_id = gateway_cluster_id

    @property
    def is_enabled(self):
        """Gets the is_enabled of this NotiForwarder.  # noqa: E501


        :return: The is_enabled of this NotiForwarder.  # noqa: E501
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """Sets the is_enabled of this NotiForwarder.


        :param is_enabled: The is_enabled of this NotiForwarder.  # noqa: E501
        :type: bool
        """

        self._is_enabled = is_enabled

    @property
    def last_version(self):
        """Gets the last_version of this NotiForwarder.  # noqa: E501


        :return: The last_version of this NotiForwarder.  # noqa: E501
        :rtype: int
        """
        return self._last_version

    @last_version.setter
    def last_version(self, last_version):
        """Sets the last_version of this NotiForwarder.


        :param last_version: The last_version of this NotiForwarder.  # noqa: E501
        :type: int
        """

        self._last_version = last_version

    @property
    def modification_date(self):
        """Gets the modification_date of this NotiForwarder.  # noqa: E501


        :return: The modification_date of this NotiForwarder.  # noqa: E501
        :rtype: datetime
        """
        return self._modification_date

    @modification_date.setter
    def modification_date(self, modification_date):
        """Sets the modification_date of this NotiForwarder.


        :param modification_date: The modification_date of this NotiForwarder.  # noqa: E501
        :type: datetime
        """

        self._modification_date = modification_date

    @property
    def noti_forwarder_id(self):
        """Gets the noti_forwarder_id of this NotiForwarder.  # noqa: E501


        :return: The noti_forwarder_id of this NotiForwarder.  # noqa: E501
        :rtype: int
        """
        return self._noti_forwarder_id

    @noti_forwarder_id.setter
    def noti_forwarder_id(self, noti_forwarder_id):
        """Sets the noti_forwarder_id of this NotiForwarder.


        :param noti_forwarder_id: The noti_forwarder_id of this NotiForwarder.  # noqa: E501
        :type: int
        """

        self._noti_forwarder_id = noti_forwarder_id

    @property
    def noti_forwarder_name(self):
        """Gets the noti_forwarder_name of this NotiForwarder.  # noqa: E501


        :return: The noti_forwarder_name of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._noti_forwarder_name

    @noti_forwarder_name.setter
    def noti_forwarder_name(self, noti_forwarder_name):
        """Sets the noti_forwarder_name of this NotiForwarder.


        :param noti_forwarder_name: The noti_forwarder_name of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._noti_forwarder_name = noti_forwarder_name

    @property
    def noti_forwarder_type(self):
        """Gets the noti_forwarder_type of this NotiForwarder.  # noqa: E501


        :return: The noti_forwarder_type of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._noti_forwarder_type

    @noti_forwarder_type.setter
    def noti_forwarder_type(self, noti_forwarder_type):
        """Sets the noti_forwarder_type of this NotiForwarder.


        :param noti_forwarder_type: The noti_forwarder_type of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._noti_forwarder_type = noti_forwarder_type

    @property
    def noti_forwarder_versions(self):
        """Gets the noti_forwarder_versions of this NotiForwarder.  # noqa: E501


        :return: The noti_forwarder_versions of this NotiForwarder.  # noqa: E501
        :rtype: list[ItemVersion]
        """
        return self._noti_forwarder_versions

    @noti_forwarder_versions.setter
    def noti_forwarder_versions(self, noti_forwarder_versions):
        """Sets the noti_forwarder_versions of this NotiForwarder.


        :param noti_forwarder_versions: The noti_forwarder_versions of this NotiForwarder.  # noqa: E501
        :type: list[ItemVersion]
        """

        self._noti_forwarder_versions = noti_forwarder_versions

    @property
    def paths(self):
        """Gets the paths of this NotiForwarder.  # noqa: E501


        :return: The paths of this NotiForwarder.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this NotiForwarder.


        :param paths: The paths of this NotiForwarder.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def protection_key(self):
        """Gets the protection_key of this NotiForwarder.  # noqa: E501


        :return: The protection_key of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._protection_key

    @protection_key.setter
    def protection_key(self, protection_key):
        """Sets the protection_key of this NotiForwarder.


        :param protection_key: The protection_key of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._protection_key = protection_key

    @property
    def runner_type(self):
        """Gets the runner_type of this NotiForwarder.  # noqa: E501


        :return: The runner_type of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._runner_type

    @runner_type.setter
    def runner_type(self, runner_type):
        """Sets the runner_type of this NotiForwarder.


        :param runner_type: The runner_type of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._runner_type = runner_type

    @property
    def timespan_in_seconds(self):
        """Gets the timespan_in_seconds of this NotiForwarder.  # noqa: E501


        :return: The timespan_in_seconds of this NotiForwarder.  # noqa: E501
        :rtype: int
        """
        return self._timespan_in_seconds

    @timespan_in_seconds.setter
    def timespan_in_seconds(self, timespan_in_seconds):
        """Sets the timespan_in_seconds of this NotiForwarder.


        :param timespan_in_seconds: The timespan_in_seconds of this NotiForwarder.  # noqa: E501
        :type: int
        """

        self._timespan_in_seconds = timespan_in_seconds

    @property
    def to_emails(self):
        """Gets the to_emails of this NotiForwarder.  # noqa: E501


        :return: The to_emails of this NotiForwarder.  # noqa: E501
        :rtype: list[EmailEntry]
        """
        return self._to_emails

    @to_emails.setter
    def to_emails(self, to_emails):
        """Sets the to_emails of this NotiForwarder.


        :param to_emails: The to_emails of this NotiForwarder.  # noqa: E501
        :type: list[EmailEntry]
        """

        self._to_emails = to_emails

    @property
    def username(self):
        """Gets the username of this NotiForwarder.  # noqa: E501


        :return: The username of this NotiForwarder.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this NotiForwarder.


        :param username: The username of this NotiForwarder.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def with_customer_fragment(self):
        """Gets the with_customer_fragment of this NotiForwarder.  # noqa: E501


        :return: The with_customer_fragment of this NotiForwarder.  # noqa: E501
        :rtype: bool
        """
        return self._with_customer_fragment

    @with_customer_fragment.setter
    def with_customer_fragment(self, with_customer_fragment):
        """Sets the with_customer_fragment of this NotiForwarder.


        :param with_customer_fragment: The with_customer_fragment of this NotiForwarder.  # noqa: E501
        :type: bool
        """

        self._with_customer_fragment = with_customer_fragment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotiForwarder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NotiForwarder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.certificate_info import CertificateInfo  # noqa: E501
from akeyless.rest import ApiException

class TestCertificateInfo(unittest.TestCase):
    """CertificateInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CertificateInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.certificate_info.CertificateInfo()  # noqa: E501
        if include_optional :
            return CertificateInfo(
                ext_key_usage = [
                    56
                    ], 
                key_usage = 56, 
                dns_names = [
                    '0'
                    ], 
                email_addresses = [
                    '0'
                    ], 
                extensions = [
                    akeyless.models.extension.Extension(
                        critical = True, 
                        name = '0', 
                        value = '0', )
                    ], 
                ip_addresses = [
                    '0'
                    ], 
                is_ca = True, 
                issuer = akeyless.models.name.Name(
                    country = [
                        '0'
                        ], 
                    extra_names = [
                        akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                            type = [
                                56
                                ], 
                            value = akeyless.models.value.Value(), )
                        ], 
                    locality = [
                        '0'
                        ], 
                    names = [
                        akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                            type = [
                                56
                                ], 
                            value = akeyless.models.value.Value(), )
                        ], 
                    serial_number = '0', 
                    street_address = [
                        '0'
                        ], ), 
                issuing_certificate_url = [
                    '0'
                    ], 
                key_size = 56, 
                not_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                not_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                ocsp_server = [
                    '0'
                    ], 
                public_key_algorithm_name = '0', 
                serial_number = '0', 
                sha_1_fingerprint = '0', 
                sha_256_fingerprint = '0', 
                signature = '0', 
                signature_algorithm_name = '0', 
                subject = akeyless.models.name.Name(
                    country = [
                        '0'
                        ], 
                    extra_names = [
                        akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                            type = [
                                56
                                ], 
                            value = akeyless.models.value.Value(), )
                        ], 
                    locality = [
                        '0'
                        ], 
                    names = [
                        akeyless.models.attribute_type_and_value.AttributeTypeAndValue(
                            type = [
                                56
                                ], 
                            value = akeyless.models.value.Value(), )
                        ], 
                    serial_number = '0', 
                    street_address = [
                        '0'
                        ], ), 
                subject_public_key = '0', 
                uris = [
                    '0'
                    ], 
                version = 56
            )
        else :
            return CertificateInfo(
        )

    def testCertificateInfo(self):
        """Test CertificateInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
